@@ -17,7 +17,8 @@ from typing import Any, Dict, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_redshift_data.paginator import (
+from .literals import StatusStringType
+from .paginator import (
     DescribeTablePaginator,
     GetStatementResultPaginator,
     ListDatabasesPaginator,
@@ -25,8 +26,6 @@ from mypy_boto3_redshift_data.paginator import (
     ListStatementsPaginator,
     ListTablesPaginator,
 )
-
-from .literals import StatusString
 from .type_defs import (
     CancelStatementResponseTypeDef,
     DescribeStatementResponseTypeDef,
@@ -67,7 +66,7 @@ class Exceptions:
 
 class RedshiftDataAPIServiceClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -76,20 +75,20 @@ class RedshiftDataAPIServiceClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def cancel_statement(self, Id: str) -> CancelStatementResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Client.cancel_statement)
-        [Show boto3-stubs documentation](./client.md#cancel-statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Client.cancel_statement)
+        [Show boto3-stubs documentation](./client.md#cancel_statement)
         """
 
     def describe_statement(self, Id: str) -> DescribeStatementResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_statement)
-        [Show boto3-stubs documentation](./client.md#describe-statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_statement)
+        [Show boto3-stubs documentation](./client.md#describe_statement)
         """
 
     def describe_table(
@@ -105,8 +104,8 @@ class RedshiftDataAPIServiceClient:
         Table: str = None,
     ) -> DescribeTableResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_table)
-        [Show boto3-stubs documentation](./client.md#describe-table)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Client.describe_table)
+        [Show boto3-stubs documentation](./client.md#describe_table)
         """
 
     def execute_statement(
@@ -120,8 +119,8 @@ class RedshiftDataAPIServiceClient:
         WithEvent: bool = None,
     ) -> ExecuteStatementOutputTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Client.execute_statement)
-        [Show boto3-stubs documentation](./client.md#execute-statement)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Client.execute_statement)
+        [Show boto3-stubs documentation](./client.md#execute_statement)
         """
 
     def generate_presigned_url(
@@ -132,16 +131,16 @@ class RedshiftDataAPIServiceClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_statement_result(
         self, Id: str, NextToken: str = None
     ) -> GetStatementResultResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Client.get_statement_result)
-        [Show boto3-stubs documentation](./client.md#get-statement-result)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Client.get_statement_result)
+        [Show boto3-stubs documentation](./client.md#get_statement_result)
         """
 
     def list_databases(
@@ -154,8 +153,8 @@ class RedshiftDataAPIServiceClient:
         SecretArn: str = None,
     ) -> ListDatabasesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_databases)
-        [Show boto3-stubs documentation](./client.md#list-databases)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_databases)
+        [Show boto3-stubs documentation](./client.md#list_databases)
         """
 
     def list_schemas(
@@ -170,8 +169,8 @@ class RedshiftDataAPIServiceClient:
         SecretArn: str = None,
     ) -> ListSchemasResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_schemas)
-        [Show boto3-stubs documentation](./client.md#list-schemas)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_schemas)
+        [Show boto3-stubs documentation](./client.md#list_schemas)
         """
 
     def list_statements(
@@ -180,11 +179,11 @@ class RedshiftDataAPIServiceClient:
         NextToken: str = None,
         RoleLevel: bool = None,
         StatementName: str = None,
-        Status: StatusString = None,
+        Status: StatusStringType = None,
     ) -> ListStatementsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_statements)
-        [Show boto3-stubs documentation](./client.md#list-statements)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_statements)
+        [Show boto3-stubs documentation](./client.md#list_statements)
         """
 
     def list_tables(
@@ -200,14 +199,14 @@ class RedshiftDataAPIServiceClient:
         TablePattern: str = None,
     ) -> ListTablesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_tables)
-        [Show boto3-stubs documentation](./client.md#list-tables)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Client.list_tables)
+        [Show boto3-stubs documentation](./client.md#list_tables)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["describe_table"]) -> DescribeTablePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)[Show boto3-stubs documentation](./paginators.md#describetablepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable)[Show boto3-stubs documentation](./paginators.md#describetablepaginator)
         """
 
     @overload
@@ -215,29 +214,29 @@ class RedshiftDataAPIServiceClient:
         self, operation_name: Literal["get_statement_result"]
     ) -> GetStatementResultPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)[Show boto3-stubs documentation](./paginators.md#getstatementresultpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult)[Show boto3-stubs documentation](./paginators.md#getstatementresultpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_databases"]) -> ListDatabasesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)[Show boto3-stubs documentation](./paginators.md#listdatabasespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases)[Show boto3-stubs documentation](./paginators.md#listdatabasespaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_schemas"]) -> ListSchemasPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)[Show boto3-stubs documentation](./paginators.md#listschemaspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas)[Show boto3-stubs documentation](./paginators.md#listschemaspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_statements"]) -> ListStatementsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)[Show boto3-stubs documentation](./paginators.md#liststatementspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements)[Show boto3-stubs documentation](./paginators.md#liststatementspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_tables"]) -> ListTablesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)[Show boto3-stubs documentation](./paginators.md#listtablespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables)[Show boto3-stubs documentation](./paginators.md#listtablespaginator)
         """
